@@ -39,9 +39,9 @@ def readDicFile(path, appendDic = False):
 		readDic = True
 		dicFile.close()
 	except FileNotFoundError:
-		print("Error: File not found")
+		print("Error: File not found", path)
 	except:
-		print("Error while reading the file")
+		print("Error while reading the file", path)
 	return readDic
 
 def dictionaryAttackWindows(hashesFile, dictionary = None, appendDic = False):
@@ -145,7 +145,4 @@ def dictionaryAttackUnix(hashesFile, dictionary = None, appendDic = False):
 					break
 			if not passwdFind:
 				print('[-] Password not found for the user '+username+'\n')
-		hashes.close()
-
-
-dictionaryAttackWindows('../../TFM_docs/hashes', '../../TFM_docs/dict')
+		hashes.close()
\ No newline at end of file
